# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Table(Component):
    """A Table component.
Table is a component that displays data in a tabular format.
It takes a property `data` which is an array of objects representing the table rows.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- data (list of dicts; optional):
    The data to be displayed in the table. It should be an array of
    objects, where each object represents a row.

- dense (boolean; default False):
    If True, the table will be rendered in a dense layout.

- stickyHeader (boolean; default False):
    If True, the table header will be sticky."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Table'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, dense=Component.UNDEFINED, stickyHeader=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'data', 'dense', 'stickyHeader']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'data', 'dense', 'stickyHeader']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Table, self).__init__(**args)
